# MLE-agent

## Installation

```bash
pip install -e .
```

## Usage

You need to set an OpenAI API key before running the agent. You can use the CLI to set the key:

```bash
mle config
```

## License

Check [LICENSE](LICENSE) file for more information.


